@@ -1,11 +1,20 @@
+# NOTE: Since the intention is to ship this file with a project, this file
+# cannot have any non-core dependencies.
+package Sub::HandlesVia::Mite;
 use 5.008001;
 use strict;
 use warnings;
+no strict 'refs';
 
-# NOTE: Since the intention is to ship this file with a project, this file
-# cannot have any non-core dependencies.
+if ( $] < 5.009005 ) { require MRO::Compat; }
+else                 { require mro;         }
 
-package Sub::HandlesVia::Mite;
+defined ${^GLOBAL_PHASE}
+or eval { require Devel::GlobalDestruction; 1 }
+or do {
+    carp( "WARNING: Devel::GlobalDestruction recommended!" );
+    *Devel::GlobalDestruction::in_global_destruction = sub { undef; };
+};
 
 # Constants
 sub true  () { !!1 }
@@ -16,6 +25,14 @@ sub rwp   () { 'rwp' }
 sub lazy  () { 'lazy' }
 sub bare  () { 'bare' }
 
+# More complicated constants
+BEGIN {
+    my @bool = ( \&false, \&true );
+    *_HAS_AUTOCLEAN = $bool[ 0+!! eval { require namespace::autoclean } ];
+    *STRICT         = $bool[ 0+!! ( $ENV{PERL_STRICT} || $ENV{EXTENDED_TESTING} || $ENV{AUTHOR_TESTING} || $ENV{RELEASE_TESTING} ) ];
+};
+
+# Exportable error handlers
 sub _error_handler {
     my ( $func, $message, @args ) = @_;
     if ( @args ) {
@@ -26,7 +43,7 @@ sub _error_handler {
             ref($_) ? Data::Dumper::Dumper($_) : defined($_) ? $_ : '(undef)'
         } @args;
     }
-    my $next = do { no strict 'refs'; require Carp; \&{"Carp::$func"} };
+    my $next = do { require Carp; \&{"Carp::$func"} };
     @_ = ( $message );
     goto $next;
 }
@@ -35,65 +52,32 @@ sub carp    { unshift @_, 'carp'   ; goto \&_error_handler }
 sub croak   { unshift @_, 'croak'  ; goto \&_error_handler }
 sub confess { unshift @_, 'confess'; goto \&_error_handler }
 
-BEGIN {
-    my @bool = ( \&false, \&true );
-    *_HAS_AUTOCLEAN = $bool[ 0+!! eval { require namespace::autoclean } ];
-    *STRICT         = $bool[ 0+!! ( $ENV{PERL_STRICT} || $ENV{EXTENDED_TESTING} || $ENV{AUTHOR_TESTING} || $ENV{RELEASE_TESTING} ) ];
-};
-
-if ( $] < 5.009005 ) {
-    require MRO::Compat;
-}
-else {
-    require mro;
-}
-
-defined ${^GLOBAL_PHASE}
-or eval { require Devel::GlobalDestruction; 1 }
-or do {
-    carp( "WARNING: Devel::GlobalDestruction recommended!" );
-    *Devel::GlobalDestruction::in_global_destruction = sub { undef; };
-};
-
+# Exportable guard function
 {
-    no strict 'refs';
     my $GUARD_PACKAGE = __PACKAGE__ . '::Guard';
-    *{"$GUARD_PACKAGE\::DESTROY"} = sub { $_[0][1]->() unless $_[0][0] };
-    *{"$GUARD_PACKAGE\::restore"} = sub { $_[0]->DESTROY; $_[0][0] = 1 };
-    *{"$GUARD_PACKAGE\::dismiss"} = sub {                 $_[0][0] = 1 };
+    *{"$GUARD_PACKAGE\::DESTROY"} = sub { $_[0][0] or $_[0][1]->() };
+    *{"$GUARD_PACKAGE\::restore"} = sub { $_[0]->DESTROY; $_[0][0] = true };
+    *{"$GUARD_PACKAGE\::dismiss"} = sub {                 $_[0][0] = true };
     *{"$GUARD_PACKAGE\::peek"}    = sub { $_[0][2] };
     *guard = sub (&) { bless [ 0, @_ ] => $GUARD_PACKAGE };
 }
 
-my $parse_mm_args = sub {
-    my $coderef = pop;
-    my $names   = [ map { ref($_) ? @$_ : $_ } @_ ];
-    ( $names, $coderef );
-};
-
 sub _is_compiling {
     return !! $ENV{MITE_COMPILE};
 }
 
 sub import {
-    my $class = shift;
+    my $me = shift;
     my %arg = map { lc($_) => true } @_;
     my ( $caller, $file ) = caller;
 
-    # Turn on warnings and strict in the caller
-    warnings->import;
-    strict->import;
-
-    my $kind = $arg{'-role'} ? 'role' : 'class';
-
     if( _is_compiling() ) {
         require Mite::Project;
         Mite::Project->default->inject_mite_functions(
-            package     => $caller,
-            file        => $file,
-            arg         => \%arg,
-            kind        => $kind,
-            shim        => $class,
+            package => $caller,
+            file    => $file,
+            arg     => \%arg,
+            shim    => $me,
         );
     }
     else {
@@ -107,118 +91,18 @@ sub import {
             local @INC = ('.', @INC);
             require $mite_file;
         }
-
-        $class->_inject_mite_functions( $caller, $file, $kind, \%arg );
     }
 
-    if ( _HAS_AUTOCLEAN and not $arg{'-unclean'} ) {
-        'namespace::autoclean'->import( -cleanee => $caller );
-    }
-}
-
-sub _inject_mite_functions {
-    my ( $class, $caller, $file, $kind, $arg ) = ( shift, @_ );
-    my $requested = sub { $arg->{$_[0]} ? true : $arg->{'!'.$_[0]} ? false : $arg->{'-all'} ? true : $_[1]; };
-
-    no strict 'refs';
-    my $has = $class->_make_has( $caller, $file, $kind );
-    *{"$caller\::has"}   = $has if $requested->( has   => true  );
-    *{"$caller\::param"} = $has if $requested->( param => false );
-    *{"$caller\::field"} = $has if $requested->( field => false );
-
-    *{"$caller\::with"} = $class->_make_with( $caller, $file, $kind )
-        if $requested->( with => true );
-
-    *{"$caller\::signature_for"} = sub {
-        my ( $name ) = @_;
-        $name =~ s/^\+//;
-        $class->around( $caller, $name, ${"$caller\::SIGNATURE_FOR"}{$name} );
-    } if $requested->( signature_for => false );
-
-    *{"$caller\::extends"} = sub {}
-        if $kind eq 'class' && $requested->( extends => true );
-    *{"$caller\::requires"} = sub {}
-        if $kind eq 'role' && $requested->( requires => true );
-
-    my $MM = ( $kind eq 'class' ) ? [] : \@{"$caller\::METHOD_MODIFIERS"};
-
-    for my $modifier ( qw/ before after around / ) {
-        next unless $requested->( $modifier => true );
-
-        if ( $kind eq 'class' ) {
-            *{"$caller\::$modifier"} = sub {
-                $class->$modifier( $caller, @_ );
-                return;
-            };
-        }
-        else {
-            *{"$caller\::$modifier"} = sub {
-                my ( $names, $coderef ) = &$parse_mm_args;
-                push @$MM, [ $modifier, $names, $coderef ];
-                return;
-            };
-        }
-    }
-}
-
-sub _make_has {
-    my ( $class, $caller, $file, $kind ) = @_;
-
-    no strict 'refs';
-    return sub {
-        my $names = shift;
-        if ( @_ % 2 ) {
-            my $default = shift;
-            unshift @_, ( 'CODE' eq ref( $default ) )
-                ? ( is => lazy, builder => $default )
-                : ( is => ro, default => $default );
-        }
-        my %spec = @_;
-        my $code;
-
-        for my $name ( ref($names) ? @$names : $names ) {
-           $name =~ s/^\+//;
-
-           'CODE' eq ref( $code = $spec{default} )
-               and ${"$caller\::__$name\_DEFAULT__"} = $code;
-
-           'CODE' eq ref( $code = $spec{builder} )
-               and *{"$caller\::_build_$name"} = $code;
-
-           'CODE' eq ref( $code = $spec{trigger} )
-               and *{"$caller\::_trigger_$name"} = $code;
-
-           'CODE' eq ref( $code = $spec{clone} )
-               and *{"$caller\::_clone_$name"} = $code;
-        }
-
-        return;
-    };
-}
-
-sub _make_with {
-    my ( $class, $caller, $file, $kind ) = @_;
-
-    return sub {
-        while ( @_ ) {
-            my $role = shift;
-            my $args = ref($_[0]) ? shift : undef;
-            if ( $INC{'Role/Tiny.pm'} and 'Role::Tiny'->is_role( $role ) ) {
-                $class->_finalize_application_roletiny( $role, $caller, $args );
-            }
-            else {
-                $role->__FINALIZE_APPLICATION__( $caller, $args );
-            }
-        }
-        return;
-    };
+    warnings->import;
+    strict->import;
+    'namespace::autoclean'->import( -cleanee => $caller )
+        if _HAS_AUTOCLEAN && !$arg{'-unclean'};
 }
 
 {
     my ( $cb_before, $cb_after );
     sub _finalize_application_roletiny {
-        my ( $class, $role, $caller, $args ) = @_;
-
+        my ( $me, $role, $caller, $args ) = @_;
         if ( $INC{'Role/Hooks.pm'} ) {
             $cb_before ||= \%Role::Hooks::CALLBACKS_BEFORE_APPLY;
             $cb_after  ||= \%Role::Hooks::CALLBACKS_AFTER_APPLY;
@@ -226,39 +110,90 @@ sub _make_with {
         if ( $cb_before ) {
             $_->( $role, $caller ) for @{ $cb_before->{$role} || [] };
         }
-
         'Role::Tiny'->_check_requires( $caller, $role );
-
         my $info = $Role::Tiny::INFO{$role};
         for ( @{ $info->{modifiers} || [] } ) {
-            my @args = @$_;
-            my $kind = shift @args;
-            $class->$kind( $caller, @args );
+            my @args         = @$_;
+            my $modification = shift @args;
+            my $handler      = "HANDLE_$modification";
+            $me->$handler( $caller, undef, @args );
         }
-
         if ( $cb_after ) {
             $_->( $role, $caller ) for @{ $cb_after->{$role} || [] };
         }
+        return;
+    }
 
+    # Usage: $me, $caller, @with_args
+    sub HANDLE_with {
+        my ( $me, $caller ) = ( shift, shift );
+        while ( @_ ) {
+            my $role = shift;
+            my $args = ref($_[0]) ? shift : undef;
+            if ( $INC{'Role/Tiny.pm'} and 'Role::Tiny'->is_role( $role ) ) {
+                $me->_finalize_application_roletiny( $role, $caller, $args );
+            }
+            else {
+                $role->__FINALIZE_APPLICATION__( $caller, $args );
+            }
+        }
         return;
     }
 }
 
-{
-    my $get_orig = sub {
-        my ( $caller, $name ) = @_;
+# Usage: $me, $caller, $keyword, @has_args
+sub HANDLE_has {
+    my ( $me, $caller, $keyword, $names ) = ( shift, shift, shift, shift );
+    if ( @_ % 2 ) {
+        my $default = shift;
+        unshift @_, ( 'CODE' eq ref( $default ) )
+            ? ( is => lazy, builder => $default )
+            : ( is => ro, default => $default );
+    }
+    my %spec = @_;
+    my $code;
+    for my $name ( ref($names) ? @$names : $names ) {
+        $name =~ s/^\+//;
+        'CODE' eq ref( $code = $spec{default} )
+            and ${"$caller\::__$name\_DEFAULT__"} = $code;
+        'CODE' eq ref( $code = $spec{builder} )
+            and *{"$caller\::_build_$name"} = $code;
+        'CODE' eq ref( $code = $spec{trigger} )
+            and *{"$caller\::_trigger_$name"} = $code;
+        'CODE' eq ref( $code = $spec{clone} )
+            and *{"$caller\::_clone_$name"} = $code;
+    }
+    return;
+}
 
+{
+    my $_kind = sub { ${ shift() . '::USES_MITE' } =~ /Role/ ? 'role' : 'class' };
+
+    sub _get_orig_method {
+        my ( $caller, $name ) = @_;
         my $orig = $caller->can( $name );
         return $orig if $orig;
-
         croak "Cannot modify method $name in $caller: no such method";
-    };
+    }
 
-    sub before {
-        my ( $me, $caller ) = ( shift, shift );
-        my ( $names, $coderef ) = &$parse_mm_args;
+    sub _parse_mm_args {
+        my $coderef = pop;
+        my $names   = [ map { ref($_) ? @$_ : $_ } @_ ];
+        ( $names, $coderef );
+    }
+
+    # Usage: $me, $caller, $caller_kind, @before_args
+    sub HANDLE_before {
+        my ( $me, $caller, $kind ) = ( shift, shift, shift );
+        my ( $names, $coderef ) = &_parse_mm_args;
+        $kind ||= $caller->$_kind;
+        if ( $kind eq 'role' ) {
+            push @{"$caller\::METHOD_MODIFIERS"},
+                [ before => $names, $coderef ];
+            return;
+        }
         for my $name ( @$names ) {
-            my $orig = $get_orig->( $caller, $name );
+            my $orig = _get_orig_method( $caller, $name );
             local $@;
             eval <<"BEFORE" or die $@;
                 package $caller;
@@ -273,11 +208,18 @@ BEFORE
         return;
     }
 
-    sub after {
-        my ( $me, $caller ) = ( shift, shift );
-        my ( $names, $coderef ) = &$parse_mm_args;
+    # Usage: $me, $caller, $caller_kind, @after_args
+    sub HANDLE_after {
+        my ( $me, $caller, $kind ) = ( shift, shift, shift );
+        my ( $names, $coderef ) = &_parse_mm_args;
+        $kind ||= $caller->$_kind;
+        if ( $kind eq 'role' ) {
+            push @{"$caller\::METHOD_MODIFIERS"},
+                [ after => $names, $coderef ];
+            return;
+        }
         for my $name ( @$names ) {
-            my $orig = $get_orig->( $caller, $name );
+            my $orig = _get_orig_method( $caller, $name );
             local $@;
             eval <<"AFTER" or die $@;
                 package $caller;
@@ -303,11 +245,18 @@ AFTER
         return;
     }
 
-    sub around {
-        my ( $me, $caller ) = ( shift, shift );
-        my ( $names, $coderef ) = &$parse_mm_args;
+    # Usage: $me, $caller, $caller_kind, @around_args
+    sub HANDLE_around {
+        my ( $me, $caller, $kind ) = ( shift, shift, shift );
+        my ( $names, $coderef ) = &_parse_mm_args;
+        $kind ||= $caller->$_kind;
+        if ( $kind eq 'role' ) {
+            push @{"$caller\::METHOD_MODIFIERS"},
+                [ around => $names, $coderef ];
+            return;
+        }
         for my $name ( @$names ) {
-            my $orig = $get_orig->( $caller, $name );
+            my $orig = _get_orig_method( $caller, $name );
             local $@;
             eval <<"AROUND" or die $@;
                 package $caller;
@@ -322,38 +271,12 @@ AROUND
     }
 }
 
+# Usage: $me, $caller, $caller_kind, @signature_for_args
+sub HANDLE_signature_for {
+    my ( $me, $caller, $kind, $name ) = @_;
+    $name =~ s/^\+//;
+    $me->HANDLE_around( $caller, $kind, $name, ${"$caller\::SIGNATURE_FOR"}{$name} );
+    return;
+}
+
 1;
-__END__
-
-=pod
-
-=head1 NAME
-
-Sub::HandlesVia::Mite - shim to load .mite.pm files
-
-=head1 DESCRIPTION
-
-This is a copy of L<Mite::Shim>.
-
-=head1 AUTHOR
-
-Michael G Schwern E<lt>mschwern@cpan.orgE<gt>.
-
-Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
-
-=head1 COPYRIGHT AND LICENCE
-
-This software is copyright (c) 2011-2014 by Michael G Schwern.
-
-This software is copyright (c) 2022 by Toby Inkster.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=head1 DISCLAIMER OF WARRANTIES
-
-THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
-WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
-MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-
-=cut
